@@ -37,13 +37,13 @@ int main(int argc, char **argv)
 
     KLocalizedString::setApplicationDomain("kubrick");
 
-    KAboutData about ("kubrick", i18n ("Kubrick"),
-            version, i18n (description),
+    KAboutData about (QStringLiteral("kubrick"), i18n ("Kubrick"),
+            QLatin1String(version), i18n (description),
             KAboutLicense::GPL,
             i18n ("&copy; 2008 Ian Wadham"),
-            "http://kde.org/applications/games/kubrick/" );
+            QStringLiteral("http://kde.org/applications/games/kubrick/") );
     about.addAuthor (i18n ("Ian Wadham"), i18n ("Author"),
-                             "iandw.au@gmail.com");
+                             QStringLiteral("iandw.au@gmail.com"));
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kubrick"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kubrickrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("kubrickui.rc"));
@@ -56,7 +56,7 @@ int main(int argc, char **argv)
     parser.process(app);
     about.processCommandLine(&parser);
 
-    Kubrick * mainWindow = 0;
+    Kubrick * mainWindow = nullptr;
 
     if (app.isSessionRestored ()) {
         RESTORE (Kubrick);
